/* Copyright Rupert Smith, 2005 to 2006, all rights reserved. */
package uk.co.thebadgerset.junit.extensions;

import junit.framework.*;

/**
 * An InstrumentedTest is one which can supply some additional instrumentation on top of the pass/fail/error behaviour
 * of normal junit tests. Tests implementing this interface must additionally supply information about how long they
 * took to run and how much memory they used.
 *
 * <p><table id="crc"><caption>CRC Card</caption>
 * <tr><th> Responsibilities
 * <tr><td> Report test run time.
 * <tr><td> Report test memory usage.
 * </table>
 *
 * @author Rupert Smith
 */
public interface InstrumentedTest extends Test
{
    /**
     * Reports how long the test took to run.
     *
     * @return The time in milliseconds that the test took to run.
     */
    public long getTestTime();

    /**
     * Reports the memory usage at the start of the test.
     *
     * @return The memory usage at the start of the test.
     */
    public long getTestStartMemory();

    /**
     * Reports the memory usage at the end of the test.
     *
     * @return The memory usage at the end of the test.
     */
    public long getTestEndMemory();

    /**
     * Resets the instrumentation values to zero, and nulls any references to held measurements so that the memory
     * can be reclaimed.
     */
    public void reset();
}
