/* Copyright Rupert Smith, 2005 to 2006, all rights reserved. */
package uk.co.thebadgerset.junit.extensions;

/**
 * This interface can be implemented by tests that want to know if they are being run concurrently. It provides
 * lifecycle notification events to tell the test implementation when test threads are being created and destroyed.
 * This can assist tests in creating and destroying resources that exist over the life of a test thread. A single
 * test thread can excute the same test many times, and often it is convenient to keep resources, for example network
 * connections, open over many test calls.
 *
 * <p/><table id="crc"><caption>CRC Card</caption>
 * <tr><th> Responsibilities
 * <tr><td> Set up per thread test fixtures.
 * <tr><td> Clean up per thread test fixtures.
 * </table>
 *
 * @author Rupert Smith
 */
public interface TestThreadAware
{
    /**
     * Called when a test thread is created.
     */
    public void threadSetUp();

    /**
     * Called when a test thread is destroyed.
     */
    public void threadTearDown();
}
