/* Copyright Rupert Smith, 2005 to 2006, all rights reserved. */
package uk.co.thebadgerset.junit.extensions;

/**
 * TimingControllerAware is an interface that tests that manipulate the timing controller should implement. It enables
 * the TK test runner to set the test up with a handle on the timing controller which the test can use to call back
 * to the test runner to manage the timers.
 *
 * <p><table id="crc"><caption>CRC Card</caption>
 * <tr><th> Responsibilities
 * <tr><td> Provide timing controller insertion point for tests.
 * </table>
 *
 * @author Rupert Smith
 */
public interface TimingControllerAware
{
    /**
     * Used by test runners that can supply a {@link TimingController} to set the controller on an aware test.
     *
     * @param controller The timing controller.
     */
    public void setTimingController(TimingController controller);

    /**
     * Aware tests should implement this to get the timing controller passed into the
     * {@link #setTimingController(TimingController)} method.
     *
     * @return The timing controller, or null if none has been set.
     */
    public TimingController getTimingController();
}
