/* Copyright Rupert Smith, 2005 to 2006, all rights reserved. */
package uk.co.thebadgerset.junit.extensions.example;

import junit.framework.Test;
import junit.framework.TestSuite;

import uk.co.thebadgerset.junit.extensions.BatchedThrottle;
import uk.co.thebadgerset.junit.extensions.SleepThrottle;
import uk.co.thebadgerset.junit.extensions.Throttle;

/**
 * Provides a {@link uk.co.thebadgerset.junit.extensions.BatchedThrottle} to test run with the accuracy tests
 * in {@link ThrottleTestPerfBase}.
 *
 * <p/><table id="crc"><caption>CRC Card</caption>
 * <tr><th> Responsibilities <th> Collaborations
 * <tr><td> Run accuracy tests on BatchedThrottle <td> {@link uk.co.thebadgerset.junit.extensions.BatchedThrottle}
 * </table>
 *
 * @author Rupert Smith
 */
public class BatchedThrottleTestPerf extends ThrottleTestPerfBase
{
    /**
     * Creates a new named sleep throttle test.
     *
     * @param name The test name.
     */
    public BatchedThrottleTestPerf(String name)
    {
        super(name);
    }

    /**
     * Compiles all the tests in this class into a suite.
     *
     * @return The test suite.
     */
    public static Test suite()
    {
        // Build a new test suite
        TestSuite suite = new TestSuite("BatchedThrottle Tests");

        suite.addTest(new BatchedThrottleTestPerf("testThrottleAccuracy"));

        return suite;
    }

    /**
     * Generates the throttle for the abstract base class to test, in this case a
     * {@link uk.co.thebadgerset.junit.extensions.BatchedThrottle}.
     *
     * @return A sleep throttle to test.
     */
    public Throttle getTestThrottle()
    {
        return new BatchedThrottle();
    }
}
