/* Copyright Rupert Smith, 2005 to 2006, all rights reserved. */
package uk.co.thebadgerset.junit.extensions.example;

import java.util.*;

import junit.framework.Test;
import junit.framework.TestSuite;

import org.apache.log4j.Logger;

import uk.co.thebadgerset.junit.extensions.AsymptoticTestCase;
import uk.co.thebadgerset.junit.extensions.TestThreadAware;

/**
 * <p/><table id="crc"><caption>CRC Card</caption>
 * <tr><th> Responsibilities <th> Collaborations
 * </table>
 *
 * @author Rupert Smith
 */
public class TestThreadAwareTestPerf extends AsymptoticTestCase implements TestThreadAware
{
    /** Used for logging. */
    private static Logger log = Logger.getLogger(TestThreadAwareTestPerf.class);

    ThreadLocal<TestThreadLocalSetup> perThreadSetup = new ThreadLocal<TestThreadLocalSetup>();

    private static class TestThreadLocalSetup
    { }

    /**
     * Creates a named thread aware test.
     *
     * @param name The test name.
     */
    public TestThreadAwareTestPerf(String name)
    {
        super(name);
    }

    /**
     * Compiles all the tests in this class into a suite.
     *
     * @return The test suite.
     */
    public static Test suite()
    {
        // Build a new test suite
        TestSuite suite = new TestSuite("Test Thread Aware Example Tests");

        suite.addTest(new TestThreadAwareTestPerf("testPerThreadFixture"));

        return suite;
    }

    /**
     * Does nothing. Improve this example by having this use some thread locals to access per thread setups.
     */
    public void testPerThreadFixture(int i)
    {
        log.debug("public void testPerThreadFixture(int i): called in thread " + Thread.currentThread().getName());
    }

    /**
     * Called when a test thread is created.
     */
    public void threadSetUp()
    {
        log.debug("public void threadSetUp(): called in thread " + Thread.currentThread().getName());
        perThreadSetup.set(new TestThreadLocalSetup());
    }

    /**
     * Called when a test thread is destroyed.
     */
    public void threadTearDown()
    {
        log.debug("public void threadTearDown(): called in thread " + Thread.currentThread().getName());
        perThreadSetup.remove();

    }
}
